@@ -69,7 +69,7 @@ class GenericGeometry(object):
         pass
 
     def __hash__(self):
-        return self.geometry.wkt
+        return hash(self.geometry.wkt)
 
     @property
     def geometry(self):
