@@ -895,7 +895,7 @@ class ThePoly(GenericGeometry):
             return super().__getitem__(item)
 
     def __hash__(self):
-        return self.geometry.wkt
+        return hash(self.geometry.wkt)
 
 
 class TheChunk(ThePoly):
