@@ -762,7 +762,7 @@ class FieldPoly(ThePoly):
         return area(obj)
 
     def __hash__(self):
-        return self.geometry.wkt
+        return hash(self.geometry.wkt)
 
 
 def get_vis_poly(polygon: FieldPoly):
